@@ -5,11 +5,10 @@ from aquests.protocols.http.request import XMLRPCRequest
 class GRPCRequest (XMLRPCRequest):
 	initial_http_version = "2.0"
 	
-	def __init__ (self, uri, method, params = (), headers = None, encoding = "utf8", auth = None, logger = None, meta = {}):
+	def __init__ (self, uri, method, params = (), headers = None, auth = None, logger = None, meta = {}):
 		self.uri = uri
 		self.method = method
 		self.params = params
-		self.encoding = encoding
 		self.auth = (auth and type (auth) is not tuple and tuple (auth.split (":", 1)) or auth)
 		self.logger = logger
 		self.meta = meta
